# encoding: UTF-8

# Copyright © Emilio González Montaña
# Licence: Attribution & no derivates
#   * Attribution to the plugin web page URL should be done if you want to use it.
#     https://redmine.ociotec.com/projects/redmine-plugin-testlink
#   * No derivates of this plugin (or partial) are allowed.
# Take a look to licence.txt file at plugin root folder for further details.

# This plugin should be reloaded in development mode.
if (Rails.env == "development")
  ActiveSupport::Dependencies.autoload_once_paths.reject!{|x| x =~ /^#{Regexp.escape(File.dirname(__FILE__))}/}
end

require_dependency "testlink/link"
require_dependency "testlink/view_hooks"

Redmine::Plugin.register :testlink do
  name              "TestLink Redmine plugin"
  author            "Emilio González Montaña"
  description       "This plugin for Redmine allows to render TestLink links into Redmine WIKI text"
  version           "0.1.0"
  url               "https://redmine.ociotec.com/projects/redmine-plugin-testlink"
  author_url        "http://ociotec.com"
  requires_redmine  :version_or_higher => "2.3.0"

  settings          :default => {:testlink_base_url => "http://host/testlink"},
                    :partial => "settings/testlink_settings"
end

Redmine::WikiFormatting::Macros.register do
  desc "Macros to create links to TestLink elements.\n\n" +
       "Test case macro:\n" +
       "<pre>{{testlink(test-suite, <project-ID>, <test-suite-ID>)}}</pre>\n" +
       "Test suite macro:\n" +
       "<pre>{{testlink(test-case, <project-ID>, <test-case-ID>)}}</pre>\n" +
       "Requirement macro:\n" +
       "<pre>{{testlink(req, <project-ID>, <requirement-ID>)}}</pre>\n" +
       "Requirements specification macro:\n" +
       "<pre>{{testlink(req-spec, <project-ID>, <requirements-specification-ID>)}}</pre>\n"
  macro :testlink do |obj, args|
    TestLink::Link.new(*args).link
  end
end
