# Copyright © Emilio González Montaña
# Licence: Attribution & no derivates
#   * Attribution to the plugin web page URL should be done if you want to use it.
#     https://redmine.ociotec.com/projects/redmine-plugin-testlink
#   * No derivates of this plugin (or partial) are allowed.
# Take a look to licence.txt file at plugin root folder for further details.

require "i18n"

module TestLink
  class Link

  public

    def initialize(*args)
      testlink_base_url = Setting.plugin_testlink[:testlink_base_url]
      raise "TestLink base URL not configured" if testlink_base_url.blank?
      raise "Invalid macro parameters" if args.count != 3
      @macro_key, @project_id, @element_id = args
      @element_type = @@element_types[@macro_key]
      raise "Invalid macro key #{@macro_key.inspect}" if @element_type.nil?
    end

    def link
      if @project_id.nil? or @element_type.nil? or @element_id.nil?
        raise "Invalid macro parameters"
      end
      case @macro_key
      when "test-case"
        testlink_element_id = "#{@project_id}-#{@element_id}"
      else
        testlink_element_id = @element_id
      end
      if @element_type.include?(:testlink_level)
        url = "lib/results/printDocument.php?type=#{@element_type[:testlink_type]}" +
              "&level=#{@element_type[:testlink_level]}" +
              "&allOptionsOn=1" +
              "&format=0" +
              "&id=#{testlink_element_id}"
      else
        url = "linkto.php?tprojectPrefix=#{@project_id}" +
              "&item=#{@element_type[:testlink_type]}" +
              "&id=#{testlink_element_id}"
      end
      url = File.join(Setting.plugin_testlink[:testlink_base_url], url);
      link = "<a class=\"icon icon-testlink\" href=\"#{url}\">" +
               "#{I18n.t(@element_type[:label], :element => @element_id)}" +
             "</a>"
      return link.html_safe
    end

  private

    @@element_types = {
      "test-case" => {:testlink_type => "testcase",
                      :label => :label_test_case},
      "test-suite" => {:testlink_type => "testspec",
                       :testlink_level => "testsuite",
                       :label => :label_test_suite},
      "req"       => {:testlink_type => "req",
                      :label => :label_requirement},
      "req-spec"  => {:testlink_type => "reqspec",
                      :label => :label_requirements_specification},
    }
    @macro_key = nil
    @project_id = nil
    @element_type = nil
    @element_id = nil

  end
end